@@ -53,7 +53,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateUser(self, request):
         """更新用户基本信息
         :param request: Request instance for UpdateUser.
@@ -76,7 +75,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetUser(self, request):
         """查询子用户基本信息
         :param request: Request instance for GetUser.
@@ -99,7 +97,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeleteUser(self, request):
         """删除子用户
         :param request: Request instance for DeleteUser.
@@ -122,7 +119,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DetachUserPolicy(self, request):
         """解绑IAM用户策略
         :param request: Request instance for DetachUserPolicy.
@@ -145,7 +141,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListAttachedUserPolicies(self, request):
         """查询用户附加策略列表
         :param request: Request instance for ListAttachedUserPolicies.
@@ -168,7 +163,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListPolicyVersions(self, request):
         """查询策略版本列表
         :param request: Request instance for ListPolicyVersions.
@@ -191,7 +185,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def SetDefaultPolicyVersion(self, request):
         """设定默认策略版本
         :param request: Request instance for SetDefaultPolicyVersion.
@@ -214,7 +207,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def AttachUserPolicy(self, request):
         """附加用户策略
         :param request: Request instance for AttachUserPolicy.
@@ -237,7 +229,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeletePolicyVersion(self, request):
         """删除策略版本内容
         :param request: Request instance for DeletePolicyVersion.
@@ -260,7 +251,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetPolicyVersion(self, request):
         """查询策略版本内容
         :param request: Request instance for GetPolicyVersion.
@@ -283,7 +273,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreatePolicyVersion(self, request):
         """新建策略版本内容
         :param request: Request instance for CreatePolicyVersion.
@@ -306,7 +295,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListPolicies(self, request):
         """查询策略信息列表
         :param request: Request instance for ListPolicies.
@@ -329,7 +317,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetPolicy(self, request):
         """查询策略元数据信息
         :param request: Request instance for GetPolicy.
@@ -352,7 +339,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeletePolicy(self, request):
         """删除策略
         :param request: Request instance for DeletePolicy.
@@ -375,7 +361,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreatePolicy(self, request):
         """新建策略
         :param request: Request instance for CreatePolicy.
@@ -398,7 +383,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ChangePassword(self, request):
         """子用户修改密码
         :param request: Request instance for ChangePassword.
@@ -421,7 +405,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateLoginProfile(self, request):
         """更新子用户登录配置
         :param request: Request instance for UpdateLoginProfile.
@@ -444,7 +427,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetLoginProfile(self, request):
         """查询登录配置信息
         :param request: Request instance for GetLoginProfile.
@@ -467,7 +449,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreateAccessKey(self, request):
         """生成访问密钥
         :param request: Request instance for CreateAccessKey.
@@ -490,7 +471,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListAccessKeys(self, request):
         """查询访问密钥列表
         :param request: Request instance for ListAccessKeys.
@@ -513,7 +493,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateAccessKey(self, request):
         """更新访问密钥
         :param request: Request instance for UpdateAccessKey.
@@ -536,7 +515,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeleteAccessKey(self, request):
         """删除访问密钥
         :param request: Request instance for DeleteAccessKey.
@@ -559,7 +537,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListVirtualMFADevices(self, request):
         """查询虚拟设备列表
         :param request: Request instance for ListVirtualMFADevices.
@@ -582,7 +559,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def EnableMFADevice(self, request):
         """激活虚拟设备
         :param request: Request instance for EnableMFADevice.
@@ -605,7 +581,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeactivateMFADevice(self, request):
         """解绑虚拟设备
         :param request: Request instance for DeactivateMFADevice.
@@ -628,7 +603,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetVirtualMFADevice(self, request):
         """获取虚拟设备
         :param request: Request instance for GetVirtualMFADevice.
@@ -651,7 +625,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreateRole(self, request):
         """创建角色
         :param request: Request instance for CreateRole.
@@ -674,7 +647,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeleteRole(self, request):
         """删除角色
         :param request: Request instance for DeleteRole.
@@ -697,7 +669,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetRole(self, request):
         """查询角色基本信息
         :param request: Request instance for GetRole.
@@ -720,7 +691,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListRoles(self, request):
         """查询账号的角色列表
         :param request: Request instance for ListRoles.
@@ -743,7 +713,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def AttachRolePolicy(self, request):
         """附加角色的访问策略
         :param request: Request instance for AttachRolePolicy.
@@ -766,7 +735,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DetachRolePolicy(self, request):
         """分离角色的访问策略
         :param request: Request instance for DetachRolePolicy.
@@ -789,7 +757,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListAttachedRolePolicies(self, request):
         """查询角色附加的策略列表
         :param request: Request instance for ListAttachedRolePolicies.
@@ -812,7 +779,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateRoleTrustAccounts(self, request):
         """更新角色的信任关系
         :param request: Request instance for UpdateRoleTrustAccounts.
@@ -835,7 +801,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreateProject(self, request):
         """创建项目
         :param request: Request instance for CreateProject.
@@ -858,6 +823,27 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
+    def UpdateProjectInfo(self, request):
+        """更新项目信息
+        :param request: Request instance for UpdateProjectInfo.
+        :type request: :class:`ksyun.client.iam.v20151101.models.UpdateProjectInfoRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("UpdateProjectInfo", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
 
     def GetAccountAllProjectList(self, request):
         """获取主/子用户项目列表
@@ -881,7 +867,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetProjectInstanceList(self, request):
         """获取项目资源列表
         :param request: Request instance for GetProjectInstanceList.
@@ -904,7 +889,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateInstanceProjectId(self, request):
         """更新实例项目
         :param request: Request instance for UpdateInstanceProjectId.
@@ -927,7 +911,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListEntitiesForPolicy(self, request):
         """查询策略关联实体列表
         :param request: Request instance for ListEntitiesForPolicy.
@@ -950,7 +933,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListProjectMember(self, request):
         """查询项目成员列表
         :param request: Request instance for ListProjectMember.
@@ -973,7 +955,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeleteProjectMember(self, request):
         """删除项目成员
         :param request: Request instance for DeleteProjectMember.
@@ -996,7 +977,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def AddProjectMember(self, request):
         """添加项目成员
         :param request: Request instance for AddProjectMember.
@@ -1019,7 +999,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdateRole(self, request):
         """更新角基本描述
         :param request: Request instance for UpdateRole.
@@ -1042,7 +1021,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def UpdatePolicy(self, request):
         """更新策略描述
         :param request: Request instance for UpdatePolicy.
@@ -1065,7 +1043,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def CreateGroup(self, request):
         """创建用户组
         :param request: Request instance for CreateGroup.
@@ -1088,7 +1065,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DeleteGroup(self, request):
         """删除用户组
         :param request: Request instance for DeleteGroup.
@@ -1111,7 +1087,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DetachGroupPolicy(self, request):
         """从用户组分离策略
         :param request: Request instance for DetachGroupPolicy.
@@ -1134,7 +1109,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def AttachGroupPolicy(self, request):
         """附加策略到用户组
         :param request: Request instance for AttachGroupPolicy.
@@ -1157,7 +1131,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListGroupPolicies(self, request):
         """获取用户组权限列表
         :param request: Request instance for ListGroupPolicies.
@@ -1180,7 +1153,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def AddUserToGroup(self, request):
         """添加用户到用户组
         :param request: Request instance for AddUserToGroup.
@@ -1203,7 +1175,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetGroup(self, request):
         """获取用户组基础信息
         :param request: Request instance for GetGroup.
@@ -1226,7 +1197,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListGroupsForUser(self, request):
         """获取用户所属用户组列表
         :param request: Request instance for ListGroupsForUser.
@@ -1249,7 +1219,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListGroups(self, request):
         """获取用户组列表
         :param request: Request instance for ListGroups.
@@ -1272,7 +1241,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def RemoveUserFromGroup(self, request):
         """从用户组删除用户
         :param request: Request instance for RemoveUserFromGroup.
@@ -1295,7 +1263,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def ListAllUserAccessKeys(self, request):
         """获取子用户ak最后使用时间
         :param request: Request instance for ListAllUserAccessKeys.
@@ -1318,7 +1285,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def InsertInstanceToES(self, request):
         """非标实例插入es
         :param request: Request instance for InsertInstanceToES.
@@ -1341,7 +1307,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def DelInstanceFromES(self, request):
         """删除非标实例
         :param request: Request instance for DelInstanceFromES.
@@ -1364,7 +1329,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetAccountAllProjectsByParams(self, request):
         """根据参数获取账户项目列表
         :param request: Request instance for GetAccountAllProjectsByParams.
@@ -1387,7 +1351,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def SetUserSsoSettings(self, request):
         """设置用户SSO身份提供商信息
         :param request: Request instance for SetUserSsoSettings.
@@ -1410,7 +1373,6 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
     def GetUserSsoSettings(self, request):
         """查询用户SSO身份提供商信息
         :param request: Request instance for GetUserSsoSettings.
@@ -1433,4 +1395,24 @@ class IamClient(AbstractClient):
             else:
                 raise KsyunSDKException(e.message, e.message)
 
-
+    def GetEffectivePolicies(self, request):
+        """获取有效的策略信息
+        :param request: Request instance for GetEffectivePolicies.
+        :type request: :class:`ksyun.client.iam.v20151101.models.GetEffectivePoliciesRequest`
+        """
+        try:
+            params = request._serialize()
+            body = self.call_judge("GetEffectivePolicies", params, "application/x-www-form-urlencoded")
+            response = json.loads(body)
+            if "Error" not in response:
+                return body
+            else:
+                code = response["Error"]["Code"]
+                message = response["Error"]["Message"]
+                req_id = response["RequestId"]
+                raise KsyunSDKException(code, message, req_id)
+        except Exception as e:
+            if isinstance(e, KsyunSDKException):
+                raise
+            else:
+                raise KsyunSDKException(e.message, e.message)
